import { useState, useEffect } from 'react';
import { onAuthStateChanged } from 'firebase/auth';
import { auth } from './config/firebase';
import PetDisplay from './components/PetDisplay';
import InteractionMenu from './components/InteractionMenu';
import PetRegister from './components/PetRegister';
import AnimatedBackground from './components/AnimatedBackground';
import AuthForm from './components/auth/AuthForm';
import { Pet } from './types/Pet';
import { fetchPets } from './services/api/api';

export default function App() {
  const [pet, setPet] = useState<Pet | null>(null);
  const [isAuthenticated, setIsAuthenticated] = useState(false);
  const [isLoading, setIsLoading] = useState(true);

  useEffect(() => {
    const unsubscribe = onAuthStateChanged(auth, (user) => {
      setIsAuthenticated(!!user);
      setIsLoading(false);
    });

    return () => unsubscribe();
  }, []);

  useEffect(() => {
    if (isAuthenticated) {
      const loadPets = async () => {
        try {
          const pets = await fetchPets();
          if (pets.length > 0) {
            setPet(pets[0]);
          }
        } catch (error) {
          console.error('Error loading pets:', error);
        }
      };

      loadPets();
    }
  }, [isAuthenticated]);

  const handleCustomize = () => {
    console.log('Customize pet');
  };

  const handlePetUpdate = (updatedPet: Pet) => {
    setPet(updatedPet);
  };

  if (isLoading) {
    return (
      <div className="min-h-screen bg-gray-900 flex items-center justify-center">
        <div className="text-white">Loading...</div>
      </div>
    );
  }

  if (!isAuthenticated) {
    return (
      <>
        <AnimatedBackground />
        <div className="relative z-10">
          <AuthForm onAuthSuccess={() => setIsAuthenticated(true)} />
        </div>
      </>
    );
  }

  if (!pet) {
    return (
      <>
        <AnimatedBackground />
        <div className="relative z-10">
          <PetRegister onPetCreated={setPet} />
        </div>
      </>
    );
  }

  return (
    <>
      <AnimatedBackground />
      <div className="relative z-10 min-h-screen backdrop-blur-sm bg-gray-900/20 text-white p-4">
        <div className="max-w-4xl mx-auto grid gap-8">
          <PetDisplay
            pet={pet}
            onPetUpdate={handlePetUpdate}  // Add this prop
          />
          <InteractionMenu
            pet={pet}
            onPetUpdate={handlePetUpdate}
            onCustomize={handleCustomize}
          />
        </div>
      </div>
    </>
  );
}