import axios, { AxiosInstance, AxiosRequestConfig } from 'axios';
import { apiConfig } from './config';
import { setupInterceptors } from './interceptors';
import { ApiErrorHandler } from './error';
import { ApiResponse, RequestOptions, ApiError } from './types';

class ApiService {
  private static instance: ApiService;
  private axiosInstance: AxiosInstance;

  private constructor() {
    // Create axios instance with base configuration
    this.axiosInstance = axios.create(apiConfig);

    // Setup interceptors
    setupInterceptors(this.axiosInstance);

    // Add request interceptor
    this.axiosInstance.interceptors.request.use(
      (config) => {
        const token = localStorage.getItem('TOKEN');
        if (token) {
          config.headers.Authorization = `Bearer ${token}`;
        }
        return config;
      },
      (error) => {
        return Promise.reject(error);
      }
    );
  }

  public static getInstance(): ApiService {
    if (!ApiService.instance) {
      ApiService.instance = new ApiService();
    }
    return ApiService.instance;
  }

  private async request<T>(
    method: string,
    url: string,
    data?: any,
    options: RequestOptions = {}
  ): Promise<ApiResponse<T>> {
    try {
      const config: AxiosRequestConfig = {
        method,
        url,
        ...options,
      };

      if (data) {
        config.data = data;
      }

      const response = await this.axiosInstance.request<T>(config);

      return {
        data: response.data,
        status: response.status,
        statusText: response.statusText,
        headers: response.headers as Record<string, string>,
      };
    } catch (error) {
      throw ApiErrorHandler.handle(error as any);
    }
  }

  public async get<T>(url: string, options?: RequestOptions): Promise<ApiResponse<T>> {
    return this.request<T>('GET', url, undefined, options);
  }

  public async post<T>(url: string, data?: any, options?: RequestOptions): Promise<ApiResponse<T>> {
    return this.request<T>('POST', url, data, options);
  }

  public async put<T>(url: string, data?: any, options?: RequestOptions): Promise<ApiResponse<T>> {
    return this.request<T>('PUT', url, data, options);
  }

  public async delete<T>(url: string, options?: RequestOptions): Promise<ApiResponse<T>> {
    return this.request<T>('DELETE', url, undefined, options);
  }

  // Utility method to check if an error is a specific type
  public isNetworkError(error: ApiError): boolean {
    return ApiErrorHandler.isNetworkError(error);
  }

  public isTimeoutError(error: ApiError): boolean {
    return ApiErrorHandler.isTimeoutError(error);
  }

  public isServerError(error: ApiError): boolean {
    return ApiErrorHandler.isServerError(error);
  }

  public isClientError(error: ApiError): boolean {
    return ApiErrorHandler.isClientError(error);
  }
}

export { ApiService }